macro_rules! define_command {
($cmd_name:ident, $cmd_type:ty, $params_type:ty, $fn_name:ident, $result_type:ty) => { ... };
}Expand description
Macro to define a WebDriver BiDi command.
This macro generates a struct representing the command, an implementation block to create a new instance of the command, and an asynchronous function to send the command to the WebDriver BiDi session.
Parameters
$cmd_name: The name of the command struct to be generated.$cmd_type: The type of the command parameters.$params_type: The type of the parameters passed to the command.$fn_name: The name of the function to send the command.$result_type: The type of the result returned by the command.